Using GitHub — OppiaMobile 0.4.2 documentation

### Navigation

- index
- next |
- previous |
- OppiaMobile 0.4.2 documentation »
- Customisation »

# Using GitHub

All the OppiaMobile source code (for all components) is hosted on GitHub. So before starting to make any customisations you should make yourself familiar with how git works and create your own account on GitHub (for free).

The key advantages to using a versioning system like GitHub include:

- Good tracking of what changes have been made, when and by whom
- Built in bug and issue tracker
- Ability for others to easily take a copy (fork) of the code for their own use and keep this up to date with new features and developments in the core version.

You will find it extremely beneficial to create a proper `fork` of the code for the various OppiaMobile components rather than just taking a basic copy of the code, since a fork will allow you to easily merge in future developments, updates and bug fixes as well as submitting fixes and new features back into the core version for anyone else to take advantage of.

A couple of links to help get you started:

- setting up Git - https://help.github.com/articles/set-up-git
- forking a repository (and keeping it up to date with the original): https://help.github.com/articles/fork-a-repo

### Navigation

- index
- next |
- previous |
- OppiaMobile 0.4.2 documentation »
- Customisation »